Page 14 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 14

Home

    heap of ruins. Many bricks from these ruins were used in
    building Baghdad the capital of Iraq. It is of interest that
    Alexander the Great wished to restore Babylon, but his

    plans were cut short by his early death.
    Referring to Babylon, Isaiah stated that, "It shall
    never be inhabited, neither shall it be dwelt in from

    generation to generation:..." Isaiah 13:20.

    Although Saddam Hussein rebuilt a small section and
    has used this as a psychological rallying point for his
    followers, the ancient city has no foreseeable major
    significance in the commercial or political world. Its
    significance lies in its amazing parallel to the Mystery
    Babylon of Revelation, and to the movement in the world
    today called The New World Order.

    Ancient Babylon